import { ComputedRef, PropType } from 'vue';
import { default as TableOptionItem } from './TableOptionItem';
import { DeploymentStatus, inProgress } from './DeploymentStatus';
import { default as TableHeaderItem } from './TableHeaderItem';
import { SortingDirection } from './SortingDirection';
import { default as Pageable } from './Pageable';
declare const _default: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
    id: {
        type: StringConstructor;
        required: true;
    };
    /**
     * The title is displayed in capital letters next to the search
     */
    title: {
        type: StringConstructor;
        default: string;
    };
    waitForLoading: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * if undefinded sorting is not active
     */
    pageable: {
        type: PropType<Pageable>;
        default: undefined;
    };
    headers: {
        type: PropType<Array<TableHeaderItem>>;
        required: true;
    };
    data: {
        type: PropType<any[]>;
        required: true;
    };
    /**
     * The search is displayed if pagination is not undefined or you disable it here.
     */
    showSearch: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * A button to reload the table is displayed.
     */
    showReloadButton: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If true, whole lines are reformatted depending on the deployment state.
     */
    handleDeploymentStatus: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If the entity has no field id, another identifier must be specified here.
     */
    entityIdentifierKey: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Changes the base of the props headers.widthInPercent. The default mode is in %, but can also be changed to px.
     */
    headerWidthMode: {
        type: PropType<"%" | "px">;
        default: string;
    };
    /**
     * Turns off at true the row click. The line style is changed and the event is not thrown.
     */
    disableRowClick: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * What can be done with the selected entities. e.g. Delete. Title of the button callback when clicking it. As paramater comes an array with the values from entityIdentifierKey for the selected entities
     */
    options: {
        type: PropType<TableOptionItem[]>;
        default: () => never[];
    };
    /**
     * The options are then of course also not displayed
     */
    showCheckboxes: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If there is no data for the table, an empty cell with this text is displayed, which goes over the entire table.
     * This is also displayed in case of a failed search.
     */
    emptyDataMessage: {
        type: StringConstructor;
        default: string;
    };
    /**
     * If there is no data for the table, an empty cell with this text is displayed, which goes over the entire table.
     * This is also displayed in case of a failed search.
     */
    tableStyle: {
        type: PropType<"base" | "naked">;
        default: string;
    };
}>, {
    getHeaders: () => Array<TableHeaderItem>;
    emptyTableSize: import('vue').Ref<number, number>;
    DeploymentStatus: typeof DeploymentStatus;
    SortingDirection: typeof SortingDirection;
    searchText: import('vue').Ref<string, string>;
    headerCheck: import('vue').Ref<boolean, boolean>;
    headerIndeterminate: import('vue').Ref<boolean, boolean>;
    dataRefs: import('vue').Ref<any, any>;
    selectedIds: ComputedRef<any[]>;
    inProgress: typeof inProgress;
    disableIfInProgress: import('vue').Ref<boolean, boolean>;
    toggleFilterActive: (item: {
        id: string | number;
        text: string;
        active?: boolean;
    }, headerToFilter: TableHeaderItem) => void;
    isFilterActiv: (header: TableHeaderItem) => boolean;
    clickHeaderCheck: () => void;
    sort: (header: TableHeaderItem) => void;
    toPage: (page: number) => void;
    setDataRefs: (value?: boolean) => void;
    emitView: (row: any) => void;
    countItems: import('vue').Ref<number, number>;
}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, ("view" | "update:pageable" | "update:waitForLoading" | "update:headers" | "update" | "manual-reload")[], "view" | "update:pageable" | "update:waitForLoading" | "update:headers" | "update" | "manual-reload", import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
    id: {
        type: StringConstructor;
        required: true;
    };
    /**
     * The title is displayed in capital letters next to the search
     */
    title: {
        type: StringConstructor;
        default: string;
    };
    waitForLoading: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * if undefinded sorting is not active
     */
    pageable: {
        type: PropType<Pageable>;
        default: undefined;
    };
    headers: {
        type: PropType<Array<TableHeaderItem>>;
        required: true;
    };
    data: {
        type: PropType<any[]>;
        required: true;
    };
    /**
     * The search is displayed if pagination is not undefined or you disable it here.
     */
    showSearch: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * A button to reload the table is displayed.
     */
    showReloadButton: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If true, whole lines are reformatted depending on the deployment state.
     */
    handleDeploymentStatus: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If the entity has no field id, another identifier must be specified here.
     */
    entityIdentifierKey: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Changes the base of the props headers.widthInPercent. The default mode is in %, but can also be changed to px.
     */
    headerWidthMode: {
        type: PropType<"%" | "px">;
        default: string;
    };
    /**
     * Turns off at true the row click. The line style is changed and the event is not thrown.
     */
    disableRowClick: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * What can be done with the selected entities. e.g. Delete. Title of the button callback when clicking it. As paramater comes an array with the values from entityIdentifierKey for the selected entities
     */
    options: {
        type: PropType<TableOptionItem[]>;
        default: () => never[];
    };
    /**
     * The options are then of course also not displayed
     */
    showCheckboxes: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * If there is no data for the table, an empty cell with this text is displayed, which goes over the entire table.
     * This is also displayed in case of a failed search.
     */
    emptyDataMessage: {
        type: StringConstructor;
        default: string;
    };
    /**
     * If there is no data for the table, an empty cell with this text is displayed, which goes over the entire table.
     * This is also displayed in case of a failed search.
     */
    tableStyle: {
        type: PropType<"base" | "naked">;
        default: string;
    };
}>> & Readonly<{
    "onUpdate:pageable"?: ((...args: any[]) => any) | undefined;
    onView?: ((...args: any[]) => any) | undefined;
    "onUpdate:waitForLoading"?: ((...args: any[]) => any) | undefined;
    "onUpdate:headers"?: ((...args: any[]) => any) | undefined;
    onUpdate?: ((...args: any[]) => any) | undefined;
    "onManual-reload"?: ((...args: any[]) => any) | undefined;
}>, {
    title: string;
    showSearch: boolean;
    options: TableOptionItem[];
    pageable: Pageable;
    waitForLoading: boolean;
    showReloadButton: boolean;
    handleDeploymentStatus: boolean;
    entityIdentifierKey: string;
    headerWidthMode: "%" | "px";
    disableRowClick: boolean;
    showCheckboxes: boolean;
    emptyDataMessage: string;
    tableStyle: "base" | "naked";
}, {}, {
    BaseBadge: {
        new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
            size: {
                type: PropType<"small" | "default">;
                default: string;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
            size: {
                type: PropType<"small" | "default">;
                default: string;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {
            size: "default" | "small";
            icon: string;
        }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
            P: {};
            B: {};
            D: {};
            C: {};
            M: {};
            Defaults: {};
        }, Readonly<import('vue').ExtractPropTypes<{
            size: {
                type: PropType<"small" | "default">;
                default: string;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {}, {}, {}, {}, {
            size: "default" | "small";
            icon: string;
        }>;
        __isFragment?: never;
        __isTeleport?: never;
        __isSuspense?: never;
    } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
        size: {
            type: PropType<"small" | "default">;
            default: string;
        };
        icon: {
            type: StringConstructor;
            default: string;
        };
    }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {
        size: "default" | "small";
        icon: string;
    }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
        $slots: {
            default?(_: {}): any;
        };
    });
    SearchInput: {
        new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            placeholder: {
                type: StringConstructor;
                default: string;
            };
            classes: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
            infoText: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: PropType<"medium" | "large">;
                default: string;
            };
            flavor: {
                type: PropType<"white" | "gray">;
                default: string;
            };
            maxLength: {
                type: NumberConstructor;
                default: null;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            infoLabelContent: {
                type: PropType<undefined | import('../../helper/types/InfoLabelContent').default>;
                default: undefined;
            };
            modelValue: {
                type: PropType<string>;
            };
        }>> & Readonly<{
            "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
        }>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {
            "update:modelValue": (...args: any[]) => void;
        }, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            placeholder: {
                type: StringConstructor;
                default: string;
            };
            classes: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
            infoText: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: PropType<"medium" | "large">;
                default: string;
            };
            flavor: {
                type: PropType<"white" | "gray">;
                default: string;
            };
            maxLength: {
                type: NumberConstructor;
                default: null;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            infoLabelContent: {
                type: PropType<undefined | import('../../helper/types/InfoLabelContent').default>;
                default: undefined;
            };
            modelValue: {
                type: PropType<string>;
            };
        }>> & Readonly<{
            "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
        }>, {
            label: string;
            size: "large" | "medium";
            classes: string;
            flavor: "white" | "gray";
            disabled: boolean;
            infoLabelContent: import('../../helper/types/InfoLabelContent').default | undefined;
            placeholder: string;
            infoText: string;
            maxLength: number;
        }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
            P: {};
            B: {};
            D: {};
            C: {};
            M: {};
            Defaults: {};
        }, Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            placeholder: {
                type: StringConstructor;
                default: string;
            };
            classes: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
            infoText: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: PropType<"medium" | "large">;
                default: string;
            };
            flavor: {
                type: PropType<"white" | "gray">;
                default: string;
            };
            maxLength: {
                type: NumberConstructor;
                default: null;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            infoLabelContent: {
                type: PropType<undefined | import('../../helper/types/InfoLabelContent').default>;
                default: undefined;
            };
            modelValue: {
                type: PropType<string>;
            };
        }>> & Readonly<{
            "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
        }>, {}, {}, {}, {}, {
            label: string;
            size: "large" | "medium";
            classes: string;
            flavor: "white" | "gray";
            disabled: boolean;
            infoLabelContent: import('../../helper/types/InfoLabelContent').default | undefined;
            placeholder: string;
            infoText: string;
            maxLength: number;
        }>;
        __isFragment?: never;
        __isTeleport?: never;
        __isSuspense?: never;
    } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            required: true;
        };
        placeholder: {
            type: StringConstructor;
            default: string;
        };
        classes: {
            type: StringConstructor;
            default: string;
        };
        label: {
            type: StringConstructor;
            default: string;
        };
        infoText: {
            type: StringConstructor;
            default: string;
        };
        size: {
            type: PropType<"medium" | "large">;
            default: string;
        };
        flavor: {
            type: PropType<"white" | "gray">;
            default: string;
        };
        maxLength: {
            type: NumberConstructor;
            default: null;
        };
        disabled: {
            type: BooleanConstructor;
            default: boolean;
        };
        infoLabelContent: {
            type: PropType<undefined | import('../../helper/types/InfoLabelContent').default>;
            default: undefined;
        };
        modelValue: {
            type: PropType<string>;
        };
    }>> & Readonly<{
        "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
    }>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {
        "update:modelValue": (...args: any[]) => void;
    }, string, {
        label: string;
        size: "large" | "medium";
        classes: string;
        flavor: "white" | "gray";
        disabled: boolean;
        infoLabelContent: import('../../helper/types/InfoLabelContent').default | undefined;
        placeholder: string;
        infoText: string;
        maxLength: number;
    }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
        $slots: {
            default?(_: {}): any;
        };
    });
    TableDropdownButton: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
        dataTestId: {
            type: StringConstructor;
            default: string;
        };
        header: {
            type: PropType<TableHeaderItem>;
            required: true;
        };
        menuWidth: {
            type: StringConstructor;
            default: string;
        };
    }>, {
        isFilterActiv: () => boolean;
    }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, "filter"[], "filter", import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
        dataTestId: {
            type: StringConstructor;
            default: string;
        };
        header: {
            type: PropType<TableHeaderItem>;
            required: true;
        };
        menuWidth: {
            type: StringConstructor;
            default: string;
        };
    }>> & Readonly<{
        onFilter?: ((...args: any[]) => any) | undefined;
    }>, {
        dataTestId: string;
        menuWidth: string;
    }, {}, {
        BaseIcon: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
            name: {
                type: StringConstructor;
                required: true;
            };
            iconClass: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
        }>, {
            isLoaded: import('vue').Ref<any, any>;
        }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
            name: {
                type: StringConstructor;
                required: true;
            };
            iconClass: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {
            label: string;
            size: string;
            iconClass: string;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
        HeadlessMenu: import('vue').DefineComponent<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
        }, () => import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }> | import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }>[] | null, unknown, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, Record<string, any>, string, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps, Readonly<import('vue').ExtractPropTypes<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
        }>>, {
            as: string | Record<string, any>;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
        MenuButton: import('vue').DefineComponent<{
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }, () => import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }> | import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }>[] | null, unknown, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, Record<string, any>, string, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps, Readonly<import('vue').ExtractPropTypes<{
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }>>, {
            id: string;
            as: string | Record<string, any>;
            disabled: boolean;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
        MenuItem: import('vue').DefineComponent<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }, () => import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }> | import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }>[] | null, unknown, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, Record<string, any>, string, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps, Readonly<import('vue').ExtractPropTypes<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }>>, {
            id: string;
            as: string | Record<string, any>;
            disabled: boolean;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
        MenuItems: import('vue').DefineComponent<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            static: {
                type: BooleanConstructor;
                default: boolean;
            };
            unmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }, () => import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }> | import('vue').VNode<import('vue').RendererNode, import('vue').RendererElement, {
            [key: string]: any;
        }>[] | null, unknown, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, Record<string, any>, string, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps, Readonly<import('vue').ExtractPropTypes<{
            as: {
                type: (ObjectConstructor | StringConstructor)[];
                default: string;
            };
            static: {
                type: BooleanConstructor;
                default: boolean;
            };
            unmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            id: {
                type: StringConstructor;
                default: null;
            };
        }>>, {
            id: string;
            as: string | Record<string, any>;
            unmount: boolean;
            static: boolean;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    }, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    TableBulkButtons: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            required: true;
        };
        options: {
            type: PropType<TableOptionItem[]>;
            required: true;
        };
        selectedIds: {
            type: PropType<any>;
            required: true;
        };
        disabled: {
            type: BooleanConstructor;
            default: boolean;
        };
    }>, {
        textDialog: import('vue').Ref<string, string>;
        titleDialog: import('vue').Ref<string, string>;
        doButtonTextConfirmDialog: import('vue').Ref<string, string>;
        showDialog: import('vue').Ref<boolean, boolean>;
        dialogHandler: (option: TableOptionItem) => void;
        execCallback: () => void;
    }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, "callback-executed"[], "callback-executed", import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            required: true;
        };
        options: {
            type: PropType<TableOptionItem[]>;
            required: true;
        };
        selectedIds: {
            type: PropType<any>;
            required: true;
        };
        disabled: {
            type: BooleanConstructor;
            default: boolean;
        };
    }>> & Readonly<{
        "onCallback-executed"?: ((...args: any[]) => any) | undefined;
    }>, {
        disabled: boolean;
    }, {}, {
        SmallDeleteButton: {
            new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
                P: {};
                B: {};
                D: {};
                C: {};
                M: {};
                Defaults: {};
            }, Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, {
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }>;
            __isFragment?: never;
            __isTeleport?: never;
            __isSuspense?: never;
        } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
            circular: {
                type: BooleanConstructor;
                default: boolean;
            };
            isSubmit: {
                type: BooleanConstructor;
                default: boolean;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
        }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {
            icon: string;
            isSubmit: boolean;
            loading: boolean;
            disabled: boolean;
            circular: boolean;
        }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
            $slots: {
                default?(_: {}): any;
            };
        });
        SmallPrimaryButton: {
            new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
                P: {};
                B: {};
                D: {};
                C: {};
                M: {};
                Defaults: {};
            }, Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, {
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }>;
            __isFragment?: never;
            __isTeleport?: never;
            __isSuspense?: never;
        } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
            circular: {
                type: BooleanConstructor;
                default: boolean;
            };
            isSubmit: {
                type: BooleanConstructor;
                default: boolean;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
        }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {
            icon: string;
            isSubmit: boolean;
            loading: boolean;
            disabled: boolean;
            circular: boolean;
        }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
            $slots: {
                default?(_: {}): any;
            };
        });
        SmallButton: {
            new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                type: {
                    type: PropType<"primary" | "secondary" | "tertiary">;
                    default: string;
                };
                paddingX: {
                    type: StringConstructor;
                    default: string;
                };
                flavor: {
                    type: PropType<"base" | "branded" | "risky" | "boomi-ai" | "periwinkle">;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                type: {
                    type: PropType<"primary" | "secondary" | "tertiary">;
                    default: string;
                };
                paddingX: {
                    type: StringConstructor;
                    default: string;
                };
                flavor: {
                    type: PropType<"base" | "branded" | "risky" | "boomi-ai" | "periwinkle">;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {
                title: string;
                type: "primary" | "secondary" | "tertiary";
                paddingX: string;
                flavor: "base" | "branded" | "risky" | "boomi-ai" | "periwinkle";
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
                P: {};
                B: {};
                D: {};
                C: {};
                M: {};
                Defaults: {};
            }, Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                type: {
                    type: PropType<"primary" | "secondary" | "tertiary">;
                    default: string;
                };
                paddingX: {
                    type: StringConstructor;
                    default: string;
                };
                flavor: {
                    type: PropType<"base" | "branded" | "risky" | "boomi-ai" | "periwinkle">;
                    default: string;
                };
                circular: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                icon: {
                    type: StringConstructor;
                    default: string;
                };
                isSubmit: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                loading: {
                    type: BooleanConstructor;
                    default: boolean;
                };
                disabled: {
                    type: BooleanConstructor;
                    default: boolean;
                };
            }>> & Readonly<{}>, {}, {}, {}, {}, {
                title: string;
                type: "primary" | "secondary" | "tertiary";
                paddingX: string;
                flavor: "base" | "branded" | "risky" | "boomi-ai" | "periwinkle";
                icon: string;
                isSubmit: boolean;
                loading: boolean;
                disabled: boolean;
                circular: boolean;
            }>;
            __isFragment?: never;
            __isTeleport?: never;
            __isSuspense?: never;
        } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            type: {
                type: PropType<"primary" | "secondary" | "tertiary">;
                default: string;
            };
            paddingX: {
                type: StringConstructor;
                default: string;
            };
            flavor: {
                type: PropType<"base" | "branded" | "risky" | "boomi-ai" | "periwinkle">;
                default: string;
            };
            circular: {
                type: BooleanConstructor;
                default: boolean;
            };
            title: {
                type: StringConstructor;
                default: string;
            };
            icon: {
                type: StringConstructor;
                default: string;
            };
            isSubmit: {
                type: BooleanConstructor;
                default: boolean;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            disabled: {
                type: BooleanConstructor;
                default: boolean;
            };
        }>> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {
            title: string;
            type: "primary" | "secondary" | "tertiary";
            paddingX: string;
            flavor: "base" | "branded" | "risky" | "boomi-ai" | "periwinkle";
            icon: string;
            isSubmit: boolean;
            loading: boolean;
            disabled: boolean;
            circular: boolean;
        }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
            $slots: {
                default?(_: {}): any;
            };
        });
        DangerDialog: {
            new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                buttonCloseText: {
                    type: StringConstructor;
                    default: string;
                };
                buttonDoText: {
                    type: StringConstructor;
                    default: string;
                };
            }>> & Readonly<{
                "onClose-dialog"?: ((...args: any[]) => any) | undefined;
                "onDo-it"?: ((...args: any[]) => any) | undefined;
            }>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {
                "close-dialog": (...args: any[]) => void;
                "do-it": (...args: any[]) => void;
            }, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                buttonCloseText: {
                    type: StringConstructor;
                    default: string;
                };
                buttonDoText: {
                    type: StringConstructor;
                    default: string;
                };
            }>> & Readonly<{
                "onClose-dialog"?: ((...args: any[]) => any) | undefined;
                "onDo-it"?: ((...args: any[]) => any) | undefined;
            }>, {
                title: string;
                buttonCloseText: string;
                buttonDoText: string;
            }, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
                P: {};
                B: {};
                D: {};
                C: {};
                M: {};
                Defaults: {};
            }, Readonly<import('vue').ExtractPropTypes<{
                id: {
                    type: StringConstructor;
                    required: true;
                };
                title: {
                    type: StringConstructor;
                    default: string;
                };
                buttonCloseText: {
                    type: StringConstructor;
                    default: string;
                };
                buttonDoText: {
                    type: StringConstructor;
                    default: string;
                };
            }>> & Readonly<{
                "onClose-dialog"?: ((...args: any[]) => any) | undefined;
                "onDo-it"?: ((...args: any[]) => any) | undefined;
            }>, {}, {}, {}, {}, {
                title: string;
                buttonCloseText: string;
                buttonDoText: string;
            }>;
            __isFragment?: never;
            __isTeleport?: never;
            __isSuspense?: never;
        } & import('vue').ComponentOptionsBase<Readonly<import('vue').ExtractPropTypes<{
            id: {
                type: StringConstructor;
                required: true;
            };
            title: {
                type: StringConstructor;
                default: string;
            };
            buttonCloseText: {
                type: StringConstructor;
                default: string;
            };
            buttonDoText: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{
            "onClose-dialog"?: ((...args: any[]) => any) | undefined;
            "onDo-it"?: ((...args: any[]) => any) | undefined;
        }>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {
            "close-dialog": (...args: any[]) => void;
            "do-it": (...args: any[]) => void;
        }, string, {
            title: string;
            buttonCloseText: string;
            buttonDoText: string;
        }, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
            $slots: {
                default?(_: {}): any;
            };
        });
    }, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    UpperTitle: {
        new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<{}> & Readonly<{}>, {}, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
            P: {};
            B: {};
            D: {};
            C: {};
            M: {};
            Defaults: {};
        }, Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, {}>;
        __isFragment?: never;
        __isTeleport?: never;
        __isSuspense?: never;
    } & import('vue').ComponentOptionsBase<Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {}, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
        $slots: {
            default?(_: {}): any;
        };
    });
    TablePagination: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            required: true;
        };
        pageable: {
            type: PropType<Pageable>;
            required: true;
        };
    }>, {
        toPage: (page: number) => void;
        halfWayDown: () => void;
        halfWayUp: () => void;
    }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, "to-page"[], "to-page", import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            required: true;
        };
        pageable: {
            type: PropType<Pageable>;
            required: true;
        };
    }>> & Readonly<{
        "onTo-page"?: ((...args: any[]) => any) | undefined;
    }>, {}, {}, {
        PaginationRow: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
            currentPage: {
                type: BooleanConstructor;
                default: boolean;
            };
            padding: {
                type: StringConstructor;
                default: string;
            };
        }>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
            currentPage: {
                type: BooleanConstructor;
                default: boolean;
            };
            padding: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {
            currentPage: boolean;
            padding: string;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
        BaseIcon: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
            name: {
                type: StringConstructor;
                required: true;
            };
            iconClass: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
        }>, {
            isLoaded: import('vue').Ref<any, any>;
        }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
            name: {
                type: StringConstructor;
                required: true;
            };
            iconClass: {
                type: StringConstructor;
                default: string;
            };
            size: {
                type: StringConstructor;
                default: string;
            };
            label: {
                type: StringConstructor;
                default: string;
            };
        }>> & Readonly<{}>, {
            label: string;
            size: string;
            iconClass: string;
        }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    }, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    BaseCheckbox: import('vue').DefineComponent<{
        modelValue: boolean;
    } & import('../inputs/BaseCheckbox.vue').Props, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {
        "update:modelValue": (modelValue: boolean) => any;
    }, string, import('vue').PublicProps, Readonly<{
        modelValue: boolean;
    } & import('../inputs/BaseCheckbox.vue').Props> & Readonly<{
        "onUpdate:modelValue"?: ((modelValue: boolean) => any) | undefined;
    }>, {
        label: string;
        disabled: boolean;
        infoLabelContent: import('../../helper/types/InfoLabelContent').default;
        classLabel: string;
        indeterminate: boolean;
        infoLabelWidth: number;
    }, {}, {}, {}, string, import('vue').ComponentProvideOptions, false, {}, any>;
    BaseCell: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            default: string;
        };
        classes: {
            type: StringConstructor;
            default: string;
        };
        truncate: {
            type: BooleanConstructor;
            default: boolean;
        };
        colspan: {
            type: NumberConstructor;
            default: number;
        };
        wrapText: {
            type: BooleanConstructor;
            default: boolean;
        };
    }>, {
        getId: ComputedRef<string | undefined>;
        getDataTest: ComputedRef<string | undefined>;
    }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
        id: {
            type: StringConstructor;
            default: string;
        };
        classes: {
            type: StringConstructor;
            default: string;
        };
        truncate: {
            type: BooleanConstructor;
            default: boolean;
        };
        colspan: {
            type: NumberConstructor;
            default: number;
        };
        wrapText: {
            type: BooleanConstructor;
            default: boolean;
        };
    }>> & Readonly<{}>, {
        truncate: boolean;
        id: string;
        classes: string;
        colspan: number;
        wrapText: boolean;
    }, {}, {
        AutomationTooltip: {
            new (...args: any[]): import('vue').CreateComponentPublicInstanceWithMixins<Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & Readonly<{}> & Readonly<{}>, {}, true, {}, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, {}, any, import('vue').ComponentProvideOptions, {
                P: {};
                B: {};
                D: {};
                C: {};
                M: {};
                Defaults: {};
            }, Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, {}>;
            __isFragment?: never;
            __isTeleport?: never;
            __isSuspense?: never;
        } & import('vue').ComponentOptionsBase<Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, {}, {}, string, {}, import('vue').GlobalComponents, import('vue').GlobalDirectives, string, import('vue').ComponentProvideOptions> & import('vue').VNodeProps & import('vue').AllowedComponentProps & import('vue').ComponentCustomProps & (new () => {
            $slots: {
                default?(_: {}): any;
                default?(_: {}): any;
                default?(_: {}): any;
            };
        });
    }, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
    BounceLoader: import('vue').DefineComponent<{}, {}, any>;
    BaseIcon: import('vue').DefineComponent<import('vue').ExtractPropTypes<{
        name: {
            type: StringConstructor;
            required: true;
        };
        iconClass: {
            type: StringConstructor;
            default: string;
        };
        size: {
            type: StringConstructor;
            default: string;
        };
        label: {
            type: StringConstructor;
            default: string;
        };
    }>, {
        isLoaded: import('vue').Ref<any, any>;
    }, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
        name: {
            type: StringConstructor;
            required: true;
        };
        iconClass: {
            type: StringConstructor;
            default: string;
        };
        size: {
            type: StringConstructor;
            default: string;
        };
        label: {
            type: StringConstructor;
            default: string;
        };
    }>> & Readonly<{}>, {
        label: string;
        size: string;
        iconClass: string;
    }, {}, {}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
}, {}, string, import('vue').ComponentProvideOptions, true, {}, any>;
export default _default;
